# -*- coding: utf8 -*-
from __future__ import unicode_literals
import logging

from driverng import MessageV2, Worklist
from driverng.fixed import FixedLengthFormat
from driverng.fixed import String

logger = logging.getLogger("driverng.mixrate")


class MixrateResult(FixedLengthFormat):

    FMT_DESCRIPTION = (
        String("sequence", 4),
        String("position", 3),
        String("sample_id", 13),
        String("resu30s", 5),
        String("resu30mm", 5),
        String("resu60mm", 5),
    )


class Driver(MessageV2):
    SPEC = {"code": "mixrate", "label": "Mixrate X20"}

    def to_string(self, message):
        return message.to_string()

    def parse(self, data):
        obj = MixrateResult()
        obj.parse(data)
        return obj

    def encode_worklist(self, worklist, context):
        raise NotImplementedError("Monodirectionel")

    def decode_message(self, message):
        worklist = Worklist(context="result")
        sample = worklist.get_or_create(
            sample_id=message.sample_id.strip(),
            type="control" if message.sample_id.startswith == "QC" else "patient",
        )
        sample.rack = "{}_{}".format(message.sequence.strip(), message.position.strip())
        for test, value in [
            ("30s", message.resu30s),
            ("30mm", message.resu30mm),
            ("60mm", message.resu60mm),
        ]:
            if value:
                sample.results.add(code=test, value=value.strip())

        return worklist
